@@ -12,7 +12,7 @@
 ##############################################################################
 """Object Manager
 
-$Id: ObjectManager.py 100339 2009-05-24 17:24:00Z hannosch $
+$Id: ObjectManager.py 107529 2010-01-02 03:43:32Z davisagli $
 """
 
 from cgi import escape
@@ -617,7 +617,6 @@ class ObjectManager(CopyContainer,
         if dirname:
             raise BadRequest, 'Invalid file name %s' % escape(file)
 
-        cfg = getConfiguration()
         for impath in self._getImportPaths():
             filepath = os.path.join(impath, 'import', file)
             if os.path.exists(filepath):
@@ -663,6 +662,8 @@ class ObjectManager(CopyContainer,
             paths.append(zopehome)
         if not cfg.instancehome in paths:
             paths.append(cfg.instancehome)
+        if not cfg.clienthome in paths:
+            paths.append(cfg.clienthome)
         return paths
 
     def list_imports(self):
